@@ -12,7 +12,6 @@ import types as __types
 import inspect as __inspect
 import shutil as __shutil
 import ast as __ast
-import progressbar as __progressbar
 import json as __json
 import sys as __sys
 import readline as __readline
@@ -490,7 +489,7 @@ def __methodsFromModule__(cls):
 def __classNameFromModule__(cls):
     return [x for x in dir(cls) if __inspect.isclass(getattr(cls, x)) and x.startswith(__class_name_starts_with_modules__)]
 
-def __importModule__(modules, category, moduleName, __progressbar=None):
+def __importModule__(modules, category, moduleName):
     module_import_string = 'from .{modules}.{category}.{tool} import {toolFileName}'.format(modules=modules, category=category, tool=moduleName.replace('ht_', ''), toolFileName=moduleName)
     module_import_string_no_from = '{modules}.{category}.{tool}.{toolFileName}'.format(modules=modules, category=category, tool=moduleName.replace('ht_', ''), toolFileName=moduleName)
     try:
@@ -502,8 +501,6 @@ def __importModule__(modules, category, moduleName, __progressbar=None):
         if len(module_functions) > 0:
             __modules_loaded__[module_import_string_no_from] = {}
             for mod_func in module_functions:
-                if __progressbar:
-                    __progressbar.update(1)
                 functionParams = Utils.getFunctionsParams(category=category, moduleName=moduleName, functionName=mod_func, i_want_list=True)
                 original_params = Utils.getFunctionsParams(category=category, moduleName=moduleName, functionName=mod_func)
 
@@ -550,21 +547,21 @@ def __importModules__():
     """
     Logger.printMessage(message='{meth}'.format(meth='__importModules__'), description='Loading modules...', debug_module=True)
     modules = __getModules__()
-    with __progressbar.ProgressBar(max_value=__progressbar.UnknownLength) as bar:
-        for modu in modules:
-            for submod in modules[modu]:
-                for files in modules[modu][submod]:
-                    try:
-                        module_name = modules[modu][submod][files][0].split(".")[0]
-                        # worker("import-module-{m}".format(m=module_name), __importModule__, args=(modu, submod, module_name, bar)) # Threaded
-                        __importModule__(modules=modu, category=submod, moduleName=module_name, __progressbar=bar)
-                    except Exception as e:
-                        Logger.printMessage(message='__importModules__', description='{moduleName} File not found: {error}'.format(moduleName=files, error=str(e)), is_error=True)
-                        pass
+    for modu in modules:
+        for submod in modules[modu]:
+            for files in modules[modu][submod]:
+                try:
+                    module_name = modules[modu][submod][files][0].split(".")[0]
+                    worker("import-module-{m}".format(m=module_name), 'ht.__importModule__', args=(modu, submod, module_name), loop=False, log=False) # Threaded
+                    #__importModule__(modules=modu, category=submod, moduleName=module_name)
+                except Exception as e:
+                    Logger.printMessage(message='__importModules__', description='{moduleName} File not found: {error}'.format(moduleName=files, error=str(e)), is_error=True)
+                    pass
 
 worker('refresh-pool-servers', 'ht.Pool.__checkPoolNodes__', timesleep=180, run_until_ht_stops=True, log=__amidjango__)
 worker('clear-htpass-files', 'ht.Config.__cleanHtPassFiles__', timesleep=100, run_until_ht_stops=True, log=__amidjango__)
 worker('clear-uploaded-modules-temp', 'ht.Repositories.clearUploadsTemp', timesleep=200, run_until_ht_stops=True, log=__amidjango__)
+worker('repositories-get-online-servers', 'ht.Repositories.getOnlineServers', loop=False, run_until_ht_stops=True, log=__amidjango__)
 worker('clear-output-modules', 'ht.__cleanOutputModules__', timesleep=200, run_until_ht_stops=True, log=__amidjango__)
 
 if __telegrambot_token__:
