@@ -255,7 +255,9 @@ def __getReturnAsModalHTML__(response, main=True):
                         val = val.strftime("%d-%m-%Y %H:%M:%S")
                         res += "<div class='md-form'><label for=\"{id}\">{input_label_desc}</label><input class=\"{className}\" type=\"text\" value=\"{input_value}\" name=\"{id}\" /></div>".format(id=key, input_label_desc=key, className=input_className, input_value=val)
                     else:
+                        res += "<div class='md-form'><label for=\"{id}\">{input_label_desc}</label>".format(id=key, input_label_desc=key)
                         res += __getReturnAsModalHTML__(val, main=False)
+                        res += "</div>"
     elif isinstance(response, int):
         val_type = Utils.getValueType(response, getResponse=True)
         try:
